django-discussions
==================

.. image:: https://secure.travis-ci.org/thoas/django-discussions.png?branch=master
    :alt: Build Status
    :target: http://travis-ci.org/thoas/django-discussions

Messaging system for your users

Installation
------------

::

    pip install django-discussions


Configuration
-------------

-  Add ``'discussions'`` to your ``INSTALLED_APPS`` setting


Inspirations
------------

1. `umessages <https://github.com/bread-and-pepper/django-userena/tree/master/userena/contrib/umessages>`_ from `django-userena <http://www.django-userena.org/>`_

2. `django-postman <https://bitbucket.org/psam/django-postman/wiki/Home>`_
